@@ -1,7 +1,9 @@
 package Yancy::Plugin::Auth::Basic;
-our $VERSION = '1.014';
+our $VERSION = '1.015';
 # ABSTRACT: A simple auth module for a site
 
+#pod =encoding utf8
+#pod
 #pod =head1 SYNOPSIS
 #pod
 #pod     use Mojolicious::Lite;
@@ -107,7 +109,7 @@ our $VERSION = '1.014';
 #pod         password_digest => {
 #pod             type => 'Bcrypt',
 #pod             cost => 12,
-#pod             salt => 'abcdefghnstuff',
+#pod             salt => 'abcdefgh♥stuff',
 #pod         },
 #pod     } );
 #pod
@@ -379,7 +381,7 @@ Yancy::Plugin::Auth::Basic - A simple auth module for a site
 
 =head1 VERSION
 
-version 1.014
+version 1.015
 
 =head1 SYNOPSIS
 
@@ -412,6 +414,8 @@ This plugin provides a basic authentication and authorization scheme for
 a L<Mojolicious> site using L<Yancy>. If a user is authenticated, they are
 then authorized to use the administration application and API.
 
+=encoding utf8
+
 =head1 CONFIGURATION
 
 This plugin has the following configuration options.
@@ -486,7 +490,7 @@ Not all Digest types require additional configuration.
         password_digest => {
             type => 'Bcrypt',
             cost => 12,
-            salt => 'abcdefghnstuff',
+            salt => 'abcdefgh♥stuff',
         },
     } );
 
